# Welcome To PyLucas

This is a Python distribution made by Nuhil Lucas, designed to implement some commonly used functional modulesIts a Python Package from Nuhil Lucas.

---

注意:
因为之前的仓库整体架构和构建操作等等的问题, 导致现在 PyPi 上面存在三个版本 -> [0.0.0, 1.0.0, 3.1.1], 其中 0.0.0 是最近传上去的正确的包, 1.0.0 和 3.1.1 已经被删除了, 但是 PyPi 的规则限制即使是删除之后也不能上传同一版本号的包上去, 所以更新的时候要注意.
